@@ -46,10 +46,7 @@
 //! So the pointer is valid when this struct is alive.
 use std::any::TypeId;
 use crate::{component::{Component, ComponentStorage}, entity::EntityId, sparse_set::SparseSet, world::World};
-#[cfg(not(features = "deadlocks"))]
-use std::sync::{RwLockReadGuard, RwLockWriteGuard};
-#[cfg(features = "deadlocks")]
-use no_deadlocks::{RwLockReadGuard, RwLockWriteGuard};
+use parking_lot::{RwLockReadGuard, RwLockWriteGuard};
 
 mod with;
 mod without;
